@@ -32,7 +32,7 @@ class FileSource(DataSource):
     @property
     def _reader(self):
         if self._reader_ is None:
-            self._reader_ = reader(self.path)
+            self._reader_ = reader(self, self.path)
         return self._reader_
 
     def __iter__(self):
